c ######################################################################
c #
c #                   SILVER PROPERTIES PACKAGE
c #                   -------------------------
c #
c # Contains functions for the calculation of the thermo-physical
c # properties of pure Silver (Ag).
c #
c ######################################################################

c ######################################################################
      real function dAg(T)
c ######################################################################
c #
c # Density of Silver
c #
c # Range: 0 <= T <= inf K
c #
c #                        References
c #                        ----------
c # http://en.wikipedia.org/wiki/Silver
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   dAg               x    density                           Kg/m**3
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dAg = 10490.0
c *

      return
      end
c ######################################################################
      real function cAg(T)
c ######################################################################
c #
c # Specific heat of Silver
c #
c # Range: 1 <= T <= 300 K
c #
c #                        References
c #                        ----------
c # CryoComp version 3.0                        
c # D.R.Smith, F.R.Fickett, J. Res. NIST, 100, 119-171, (1995)
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   cAg               x    specific heat                     J/Kg K
c #
c # Author : L.Bottura and C. Rosso at Cryosoft
c # Version: 1.1   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      
      real     T0,T1
      real     Tmin,Tmax
      real     a1,a2,a3
      real     b0,b1,b2,b3,b4
      real     AA,CC,a,c,na,nc
      data     T0  /   9.785133189 / ,  T1  /  34.5580572 /
      data     a1 /6.14e-03/, a2 /-9.09e-04/, a3 /1.79e-03/
      data     b0 /-3.515882063/, b1 /0.768177822/,
     &         b2 /-0.072031/, b3 /5.59e-03/,
     &         b4 /-7.55e-05/   
      data     AA /-14331.2453/  , CC /1415.969135/
      data     a  /217.2435636/  , c /23.862111/
      data     na /1.475372864/  , nc /3.091515729/
      data     Tmin / 1.0/, Tmax / 300.0/
      save    
c * local variables
      real     TT
c *
      TT=T
      TT=max(TT,Tmin)
      TT=min(TT,Tmax)
      
      if (TT.le.T0) then
         cag = a1*TT + a2*TT**2 + a3*TT**3            
      elseif (TT.gt.T0 .and. TT.le.T1) then
         cag = b0 + b1*TT+ b2*TT**2 + b3*TT**3 + b4*TT**4      
      elseif(TT.gt.T1) then
         cag = AA*TT   /(a+TT)**na + CC*TT**3/(c+TT)**nc 
      endif
c *
      return
      end
c ######################################################################
      real function kAg(T,B,RRR)
c ######################################################################
c #
c # Thermal conductivity of Silver
c #
c # Range: 0.1 <= T <= 1000 K, 0 <= B <= 100 T,  1.5 <= RRR <= 10000
c #
c #                        References
c #                        ----------
c # CryoComp version 3.0                        
c # D.R.Smith, F.R.Fickett, J. Res. NIST, 100, 119-171, (1995)
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   B               x      magnetic field                    T
c #   RRR             x      residual resistivity ratio        -
c #   kAg               x    thermal conductivity              W/m K
c #
c # Author : L.Bottura and C. Rosso at Cryosoft
c # Version: 1.1   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,RRR
c * fit variables
      real     Tmin,Tmax
      parameter(Tmin   = 0.1, Tmax   = 1000.0)
      real     Bmin,Bmax
      parameter(Bmin   = 0.0, Bmax   = 100.0)
      real     RRRmin,RRRmax
      parameter(RRRmin = 1.5, RRRmax = 10000.0)
      real     rho273
      parameter(rho273=1.48e-8)
      real     L0
      parameter(L0=2.443e-8)
      real     alpha2,m,n,l
      parameter(alpha2=7.87561879e-8,  m=2.75,  n=2.3,  l=-2.5)      
      real     T0,k0
      parameter(T0=35.0, k0=408.59712205)      
      real     cond
c * local variables   
      real     TT,BB,R
      real     rhozero,alpha,beta,wi0,wi,w0,wt,magr
      real     magrAg

c *
      TT=T
      TT=max(TT,Tmin)
      TT=min(TT,Tmax)

      BB=B
      BB=max(BB,Bmin)
      BB=min(BB,Bmax)

      R =RRR
      R =max(R,RRRmin)
      R =min(R,RRRmax)

c *
      rhozero = rho273/(R-1.)

      beta    = rhozero/L0
      alpha   = alpha2 * (beta/n/alpha2)**((m-n)*(m+l))

c * thermal resistivity at the temperature T and zero field B
      w0      = beta/TT
      wi      = alpha*TT**n
      wi0     = wi+w0
      if(TT.le.T0) then
         wt = wi0
      else
         wt = wi0 /(1.0 + wi0 * k0*(1.0-exp(-(TT-T0)/T0)))
      endif

c * transverse magneto-resistance factor
      magr    = magrAg(TT,BB,R)
c ----------------------------------------------------------------------
c      write(6,*) TT,BB,R,rhozero,beta,alpha,w0,wi,wi0,1/wt,magr
c ----------------------------------------------------------------------

c * thermal conductivity
      kAg     = 1.0/(wt*magr)

c *      
      return
      end
c ######################################################################
      real function rAg(T,B,RRR)
c ######################################################################
c #
c # Electrical resistivity of Silver
c #
c # Range: 0.1 <= T <= 1000 K, 0 <= B <= 100 T,  1.5 <= RRR <= 10000
c #
c #                        References
c #                        ----------
c # CryoComp version 3.0                        
c # D.R.Smith, F.R.Fickett, J. Res. NIST, 100, 119-171, (1995)
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   B               x      magnetic field                    T
c #   RRR             x      residual resistivity ratio        -
c #   rAg               x    resistivity                       Ohm m
c #
c # Author : L.Bottura and C. Rosso at Cryosoft
c # Version: 1.1   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,RRR
c * fit variables
      real     Tmin,Tmax
      parameter(Tmin   = 0.1, Tmax   = 1000.0)
      real     Bmin,Bmax
      parameter(Bmin   = 0.0, Bmax   = 100.0)
      real     RRRmin,RRRmax
      parameter(RRRmin = 1.5, RRRmax = 10000.0)
      real     rho273
      parameter(rho273=1.48e-8)
      real     p1,p2,p3,p4,p5,p6,p7
      parameter(p1=1.474e-17, p2=4.82, p3=1.16e11,
     &          p4=-1.33, p5=10.0, p6=1, p7=0.333)
c * local variables   
      real     TT,BB,R,rhozero,arg,rhoi,rhoi0,rho0,magr
      real     magrAg

c *
      TT=T
      TT=max(TT,Tmin)
      TT=min(TT,Tmax)

      BB=B
      BB=max(BB,Bmin)
      BB=min(BB,Bmax)

      R =RRR
      R =max(R,RRRmin)
      R =min(R,RRRmax)
	
c * resistivity at absolute zero
      rhozero = rho273/(R-1.0)

c * resistivity at the temperature t and zero field
      arg     = min((p5/TT)**p6,30.0)
      rhoi    = p1*TT**p2/(1.+p1*p3*TT**(p2+p4)*exp(-arg))
      rhoi0   = p7*rhoi*rhozero/(rhoi+rhozero)
      rho0    = rhozero+rhoi+rhoi0

c * transverse magneto-resistance factor
      magr    = magrAg(TT,BB,R)

c * resistivity
      rAg     = magr * rho0
	
c *
      return
      end
c ######################################################################
c #
c # Auxiliary functions and calculations
c #
c ######################################################################

c ######################################################################
      real function magrAg(T,B,RRR)
c ######################################################################
c #
c # Magneto-resistivity factor of Silver, given as the ratio between
c # resistivity in transverse magnetic field b to resistivity at zero 
c # field
c #
c # Range: 0.1 <= T <= 1000 K, 0 <= B <= 100 T,  1.5 <= RRR <= 10000
c #
c #                        References
c #                        ----------
c # CryoComp version 3.0                        
c # D.R.Smith, F.R.Fickett, J. Res. NIST, 100, 119-171, (1995)
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   B               x      magnetic field                    T
c #   RRR             x      residual resistivity ratio        -
c #   magrAg            x    magneto-resistivity factor        -
c #
c # Author : L.Bottura and C. Rosso at Cryosoft
c # Version: 1.1   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T,B,RRR
c * fit variables
      real     Tmin,Tmax
      parameter(Tmin   = 0.1, Tmax   = 1000.0)
      real     Bmin,Bmax
      parameter(Bmin   = 0.0, Bmax   = 30.0)
      real     RRRmin,RRRmax
      parameter(RRRmin = 1.5, RRRmax = 10000.0)
      real     brrmin,brrmax
      parameter(brrmin = 0.0, brrmax = 10.0e3)
      real     rho273
      parameter(rho273=1.48e-8)
      real     p1,p2,p3,p4,p5,p6,p7
      parameter(p1=1.474e-17, p2=4.82, p3=1.16e11,
     &          p4=-1.33, p5=10.0, p6=1, p7=0.333)
      real     a1,a2,a3,a4
      parameter(a1=6.5e-05, a2=1.8, a3=3.0e-3, a4=1.1) 
c * local variables   
      real     TT,BB,R,rhozero,arg,rhoi,rhoi0,rho0,brr,magr

c *
      TT=T
      TT=max(TT,Tmin)
      TT=min(TT,Tmax)

      BB=B
      BB=max(BB,Bmin)
      BB=min(BB,Bmax)

      R =RRR
      R =max(R,RRRmin)
      R =min(R,RRRmax)
	
c * resistivity at absolute zero
      rhozero = rho273/(R-1.0)

c * resistivity at the temperature t
      arg     = min((p5/TT)**p6,30.0)
      rhoi    = p1*TT**p2/(1.+p1*p3*TT**(p2+p4)*exp(-arg))
      rhoi0   = p7*rhoi*rhozero/(rhoi+rhozero)
      rho0    = rhozero+rhoi+rhoi0

c * product of field and residual resistivity ratio
      brr     = BB*rho273/rho0
      brr     = max(brr,brrmin)
      brr     = min(brr,brrmax)
	
c * fit for the transverse magneto-resistance increase
      if(brr .gt. 1.) then
         magr = a1*brr**a2/(1.0+a3*brr**a4)
      else
         magr = 0.0
      endif
c ----------------------------------------------------------------------
c      write(6,*) TT,BB,R,rho0,brr,magr
c ----------------------------------------------------------------------

c * transverse magneto-resistance factor
      magrAg  = magr+1.0

c *
      return
      end


